summaryrefslogtreecommitdiffstats
path: root/kio/tests/kfiltertest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/tests/kfiltertest.cpp')
-rw-r--r--kio/tests/kfiltertest.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kio/tests/kfiltertest.cpp b/kio/tests/kfiltertest.cpp
index a0dd8fe49..901dec14e 100644
--- a/kio/tests/kfiltertest.cpp
+++ b/kio/tests/kfiltertest.cpp
@@ -20,25 +20,25 @@
#include "kfilterbase.h"
#include <unistd.h>
#include <limits.h>
-#include <qfile.h>
-#include <qtextstream.h>
+#include <tqfile.h>
+#include <tqtextstream.h>
#include <kdebug.h>
#include <kinstance.h>
-void test_block( const QString & fileName )
+void test_block( const TQString & fileName )
{
- QIODevice * dev = KFilterDev::deviceForFile( fileName );
+ TQIODevice * dev = KFilterDev::deviceForFile( fileName );
if (!dev) { kdWarning() << "dev=0" << endl; return; }
if ( !dev->open( IO_ReadOnly ) ) { kdWarning() << "open failed " << endl; return; }
- // This is what KGzipDev::readAll could do, if QIODevice::readAll was virtual....
+ // This is what KGzipDev::readAll could do, if TQIODevice::readAll was virtual....
- QByteArray array(1024);
+ TQByteArray array(1024);
int n;
while ( ( n = dev->readBlock( array.data(), array.size() ) ) )
{
kdDebug() << "readBlock returned " << n << endl << endl;
// QCString s(array,n+1); // Terminate with 0 before printing
// printf("%s", s.data());
kdDebug() << "dev.at = " << dev->at() << endl;
@@ -48,13 +48,13 @@ void test_block( const QString & fileName )
delete dev;
}
-void test_block_write( const QString & fileName )
+void test_block_write( const TQString & fileName )
{
- QIODevice * dev = KFilterDev::deviceForFile( fileName );
+ TQIODevice * dev = KFilterDev::deviceForFile( fileName );
if (!dev) { kdWarning() << "dev=0" << endl; return; }
if ( !dev->open( IO_WriteOnly ) ) { kdWarning() << "open failed " << endl; return; }
- QCString s("hello\n");
+ TQCString s("hello\n");
int ret = dev->writeBlock( s, s.size()-1 );
kdDebug() << "writeBlock ret=" << ret << endl;
//ret = dev->writeBlock( s, s.size()-1 );
@@ -63,9 +63,9 @@ void test_block_write( const QString & fileName )
delete dev;
}
-void test_getch( const QString & fileName )
+void test_getch( const TQString & fileName )
{
- QIODevice * dev = KFilterDev::deviceForFile( fileName );
+ TQIODevice * dev = KFilterDev::deviceForFile( fileName );
if (!dev) { kdWarning() << "dev=0" << endl; return; }
if ( !dev->open( IO_ReadOnly ) ) { kdWarning() << "open failed " << endl; return; }
int ch;
@@ -75,12 +75,12 @@ void test_getch( const QString & fileName )
delete dev;
}
-void test_textstream( const QString & fileName )
+void test_textstream( const TQString & fileName )
{
- QIODevice * dev = KFilterDev::deviceForFile( fileName );
+ TQIODevice * dev = KFilterDev::deviceForFile( fileName );
if (!dev) { kdWarning() << "dev=0" << endl; return; }
if ( !dev->open( IO_ReadOnly ) ) { kdWarning() << "open failed " << endl; return; }
- QTextStream ts( dev );
+ TQTextStream ts( dev );
printf("%s\n", ts.read().latin1());
dev->close();
delete dev;
@@ -92,8 +92,8 @@ int main()
char currentdir[PATH_MAX+1];
getcwd( currentdir, PATH_MAX );
- QString pathgz = QFile::decodeName(currentdir) + "/test.gz";
- QString pathbz2 = QFile::decodeName(currentdir) + "/test.bz2";
+ TQString pathgz = TQFile::decodeName(currentdir) + "/test.gz";
+ TQString pathbz2 = TQFile::decodeName(currentdir) + "/test.bz2";
kdDebug() << " -- test_block_write gzip -- " << endl;
test_block_write(pathgz);
@@ -20,25 +20,25 @@
{
kdDebug() << "readBlock returned " << n << endl << endl;
- // QCString s(array,n+1); // Terminate with 0 before printing
+ // TQCString s(array,n+1); // Terminate with 0 before printing
// printf("%s", s.data());
kdDebug() << "dev.at = " << dev->at() << endl;